%define pypi_name Jinja2

%bcond_with tests

# jinja requires itself ( as python-sphinx use it ) to build doc
%bcond_with doc

Summary:	Python template engine
Name:		python-jinja2
Version:	2.11.2
Release:	%mkrel 2
License:	BSD
Group:		Development/Python
Url:		http://jinja.pocoo.org/
Source0:	https://files.pythonhosted.org/packages/source/J/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
BuildArch:	noarch

%description
Jinja2 is a library for Python 2.4 and onwards that is designed to be
flexible, fast and secure. If you have any exposure to other
text-based template languages, such as Smarty or Django, you should
feel right at home with Jinja2. It's both designer and developer
friendly by sticking to Python's principles and adding functionality
useful for templating environments.

%package -n python3-jinja2
Summary:	General purpose template engine
Group:		Development/Python
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(markupsafe)
%if %{with tests}
BuildRequires:  python3dist(pytest)
%endif
%if %{with doc}
BuildRequires:  python3dist(sphinx)
%endif
%{?python_provide:%python_provide python3-jinja2}
Requires:	python3dist(markupsafe)
Requires:	python3dist(babel) >= 0.8

%description -n python3-jinja2
Jinja2 is a template engine written in pure Python.  It provides a
Django inspired non-XML syntax but supports inline expressions and an
optional sandboxed environment.

If you have any exposure to other text-based template languages, such
as Smarty or Django, you should feel right at home with Jinja2. It's
both designer and developer friendly by sticking to Python's
principles and adding functionality useful for templating
environments.

%prep
%setup -q -n %{pypi_name}-%{version}

perl -pi -e 's|\[pytest\]|[tool:pytest]|' setup.cfg

# cleanup
find . -name '*.pyo' -o -name '*.pyc' -delete

%build
%py3_build

%if %{with doc}
# doc build
%make_build -C docs html PYTHONPATH=$(pwd)
# clean leftovers
%__rm -rf docs/_build/html/.buildinfo

%endif

%install
%py3_install

%files -n python3-jinja2
%license LICENSE.rst
%doc README* CHANGES*
%if %{with doc}
%doc docs/_build/html
%endif
%doc ext
%doc examples
%{python3_sitelib}/*


%changelog
* Wed Jul 22 2020 ovitters <ovitters> 2.11.2-2.mga8
+ Revision: 1608050
- rebuild for get rid of pythonegg requires

* Fri Apr 17 2020 daviddavid <daviddavid> 2.11.2-1.mga8
+ Revision: 1568010
- new version: 2.11.2

* Wed Feb 19 2020 daviddavid <daviddavid> 2.11.1-1.mga8
+ Revision: 1543873
- new version: 2.11.1

* Tue Feb 18 2020 umeabot <umeabot> 2.10.3-2.mga8
+ Revision: 1538573
- Mageia 8 Mass Rebuild

* Sat Nov 23 2019 daviddavid <daviddavid> 2.10.3-1.mga8
+ Revision: 1462301
- new version: 2.10.3

* Thu Sep 05 2019 wally <wally> 2.10.1-3.mga8
+ Revision: 1437638
- rebuild for python3.8
- drop python2 support

* Mon May 13 2019 daviddavid <daviddavid> 2.10.1-2.mga7
+ Revision: 1397630
- fix upgrade mga6 -> mga7

* Fri Apr 19 2019 wally <wally> 2.10.1-1.mga7
+ Revision: 1393459
- new version 2.10.1

* Sat Jan 05 2019 wally <wally> 2.10-4.mga7
+ Revision: 1349633
- rebuild for python3.7 without docs and tests

* Thu Sep 20 2018 umeabot <umeabot> 2.10-3.mga7
+ Revision: 1289129
- Mageia 7 Mass Rebuild

* Thu Apr 26 2018 tv <tv> 2.10-2.mga7
+ Revision: 1222664
- fix upgrade

* Tue Feb 20 2018 kekepower <kekepower> 2.10-1.mga7
+ Revision: 1203732
- Update to version 2.10
- Rename python-jinja2 to python2-jinja2

* Fri Aug 04 2017 tv <tv> 2.9.6-1.mga7
+ Revision: 1134581
- fix build: remove files are valid only on Python 3.6+
+ philippem <philippem>
- update to 2.9.6

* Sun Jan 08 2017 daviddavid <daviddavid> 2.8-4.mga6
+ Revision: 1080670
- rebuild against python(3)-pytest
+ philippem <philippem>
- disable check, there are currently no tests in the jinja2 tarball
+ bcornec <bcornec>
- Fix spec file for new way of interacting with the new python-pytest

* Fri Feb 19 2016 umeabot <umeabot> 2.8-3.mga6
+ Revision: 970498
- Mageia 6 Mass Rebuild

* Wed Oct 07 2015 philippem <philippem> 2.8-2.mga6
+ Revision: 887023
- Reenable docs

* Wed Oct 07 2015 philippem <philippem> 2.8-1.mga6
+ Revision: 887008
- Update to 2.8 and bootstrap (without docs) build for Python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 2.7.3-4.mga5
+ Revision: 741538
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.7.3-3.mga5
+ Revision: 728824
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sun Jul 06 2014 philippem <philippem> 2.7.3-1.mga5
+ Revision: 644192
- update to 2.7.3

* Sat May 31 2014 pterjan <pterjan> 2.7.2-3.mga5
+ Revision: 628721
- Rebuild for new Python

* Tue Jan 21 2014 philippem <philippem> 2.7.2-2.mga4
+ Revision: 567351
- fix CVE-2014-0012 in previous CVE-2014-1402 patch

* Sat Jan 11 2014 philippem <philippem> 2.7.2-1.mga4
+ Revision: 566221
- upgrade to 2.7.2 that fix CVE-2014-1402 mga#12265

* Tue Oct 22 2013 umeabot <umeabot> 2.7.1-3.mga4
+ Revision: 543494
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.7.1-2.mga4
+ Revision: 498773
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 25 2013 philippem <philippem> 2.7.1-1.mga4
+ Revision: 471577
- Update to 2.7.1

* Tue Jul 02 2013 philippem <philippem> 2.7-1.mga4
+ Revision: 449666
- Update to 2.7, add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 2.5.5-8.mga3
+ Revision: 379029
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Feb 21 2011 ahmad <ahmad> 2.5.5-7.mga1
+ Revision: 55646
- re-enable doc building now that the pythonegg requires/provides are lowercase
  and python-sphinx can be intalled

* Mon Feb 21 2011 ahmad <ahmad> 2.5.5-6.mga1
+ Revision: 55614
- disable doc building
- rebuild to make all pythonegg requires/provides lowercase
- enable building the docs, python-sphinx is available now

* Mon Jan 17 2011 misc <misc> 2.5.5-5.mga1
+ Revision: 21027
- rebuild for python 2.7
- clean versionning, add a comment to the Obsoletes on previous version

* Thu Jan 13 2011 ahmad <ahmad> 2.5.5-4.mga1
+ Revision: 8337
- disable building the docs for now
- imported package python-jinja2


* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 2.5.5-3mdv2011.0
+ Revision: 590403
- reenable doc now python-kinja have compiled for 2.7

* Sat Oct 30 2010 Michael Scherer <misc@mandriva.org> 2.5.5-2mdv2011.0
+ Revision: 590400
- disable doc ( as jinja2 requires itself for that )
- rebuild for python 2.7

* Mon Oct 18 2010 Lev Givon <lev@mandriva.org> 2.5.5-1mdv2011.0
+ Revision: 586681
- Update to 2.5.5.

* Sun Oct 17 2010 Lev Givon <lev@mandriva.org> 2.5.4-1mdv2011.0
+ Revision: 586393
- Update to 2.5.4.

* Wed Aug 18 2010 Lev Givon <lev@mandriva.org> 2.5.2-1mdv2011.0
+ Revision: 571216
- Update to 2.5.2.

* Tue Aug 17 2010 Lev Givon <lev@mandriva.org> 2.5.1-1mdv2011.0
+ Revision: 571048
- Update to 2.5.1.
  Change to noarch because speedups are now in markupsafe package.

* Sun May 30 2010 Lev Givon <lev@mandriva.org> 2.5-1mdv2011.0
+ Revision: 546592
- Update to 2.5.

* Tue Apr 20 2010 Lev Givon <lev@mandriva.org> 2.4.1-1mdv2010.1
+ Revision: 537097
- Update to 2.4.1.

* Mon Mar 15 2010 Lev Givon <lev@mandriva.org> 2.3.1-2mdv2010.1
+ Revision: 519116
- Obsolete python-jinja.

* Fri Feb 19 2010 Frederik Himpe <fhimpe@mandriva.org> 2.3.1-1mdv2010.1
+ Revision: 508510
- Update to new version 2.3.1

* Wed Feb 10 2010 Lev Givon <lev@mandriva.org> 2.3-1mdv2010.1
+ Revision: 503884
- Update to 2.3.

* Thu Nov 12 2009 Lev Givon <lev@mandriva.org> 2.2.1-1mdv2010.1
+ Revision: 465419
- Update to 2.2.1.

* Fri May 22 2009 Lev Givon <lev@mandriva.org> 2.1.1-1mdv2010.0
+ Revision: 378570
- imported package python-jinja2


